@@ -327,14 +327,14 @@ class Parcats(_BaseTraceType):
         underscore before or after "(x|y)other" will add a space on
         that side, only when this field is shown. Numbers are formatted
         using d3-format's syntax %{variable:d3-format}, for example
-        "Price: %{y:$.2f}". https://github.com/d3/d3-3.x-api-
-        reference/blob/master/Formatting.md#d3_format for details on
-        the formatting syntax. Dates are formatted using d3-time-
-        format's syntax %{variable|d3-time-format}, for example "Day:
-        %{2019-01-01|%A}". https://github.com/d3/d3-time-
-        format#locale_format for details on the date formatting syntax.
-        The variables available in `hovertemplate` are the ones emitted
-        as event data described at this link
+        "Price: %{y:$.2f}".
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format for
+        details on the formatting syntax. Dates are formatted using
+        d3-time-format's syntax %{variable|d3-time-format}, for example
+        "Day: %{2019-01-01|%A}". https://github.com/d3/d3-time-
+        format/tree/v2.2.3#locale_format for details on the date
+        formatting syntax. The variables available in `hovertemplate`
+        are the ones emitted as event data described at this link
         https://plotly.com/javascript/plotlyjs-events/#event-data.
         Additionally, every attributes that can be specified per-point
         (the ones that are `arrayOk: true`) are available. variables
@@ -514,10 +514,10 @@ class Parcats(_BaseTraceType):
                     To control the bounds of the colorscale in
                     color space, use`line.cmin` and `line.cmax`.
                     Alternatively, `colorscale` may be a palette
-                    name string of the following list: Greys,YlGnBu
-                    ,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,Picnic,R
-                    ainbow,Portland,Jet,Hot,Blackbody,Earth,Electri
-                    c,Viridis,Cividis.
+                    name string of the following list: Blackbody,Bl
+                    uered,Blues,Cividis,Earth,Electric,Greens,Greys
+                    ,Hot,Jet,Picnic,Portland,Rainbow,RdBu,Reds,Viri
+                    dis,YlGnBu,YlOrRd.
                 colorsrc
                     Sets the source reference on Chart Studio Cloud
                     for  color .
@@ -535,17 +535,16 @@ class Parcats(_BaseTraceType):
                     only when this field is shown. Numbers are
                     formatted using d3-format's syntax
                     %{variable:d3-format}, for example "Price:
-                    %{y:$.2f}". https://github.com/d3/d3-3.x-api-
-                    reference/blob/master/Formatting.md#d3_format
-                    for details on the formatting syntax. Dates are
-                    formatted using d3-time-format's syntax
-                    %{variable|d3-time-format}, for example "Day:
-                    %{2019-01-01|%A}".
+                    %{y:$.2f}". https://github.com/d3/d3-format/tre
+                    e/v1.4.5#d3-format for details on the
+                    formatting syntax. Dates are formatted using
+                    d3-time-format's syntax %{variable|d3-time-
+                    format}, for example "Day: %{2019-01-01|%A}".
                     https://github.com/d3/d3-time-
-                    format#locale_format for details on the date
-                    formatting syntax. The variables available in
-                    `hovertemplate` are the ones emitted as event
-                    data described at this link
+                    format/tree/v2.2.3#locale_format for details on
+                    the date formatting syntax. The variables
+                    available in `hovertemplate` are the ones
+                    emitted as event data described at this link
                     https://plotly.com/javascript/plotlyjs-
                     events/#event-data. Additionally, every
                     attributes that can be specified per-point (the
@@ -894,15 +893,15 @@ class Parcats(_BaseTraceType):
             only when this field is shown. Numbers are formatted
             using d3-format's syntax %{variable:d3-format}, for
             example "Price: %{y:$.2f}".
-            https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format for
-            details on the formatting syntax. Dates are formatted
-            using d3-time-format's syntax %{variable|d3-time-
-            format}, for example "Day: %{2019-01-01|%A}".
-            https://github.com/d3/d3-time-format#locale_format for
-            details on the date formatting syntax. The variables
-            available in `hovertemplate` are the ones emitted as
-            event data described at this link
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format
+            for details on the formatting syntax. Dates are
+            formatted using d3-time-format's syntax
+            %{variable|d3-time-format}, for example "Day:
+            %{2019-01-01|%A}". https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format for details on the
+            date formatting syntax. The variables available in
+            `hovertemplate` are the ones emitted as event data
+            described at this link
             https://plotly.com/javascript/plotlyjs-events/#event-
             data. Additionally, every attributes that can be
             specified per-point (the ones that are `arrayOk: true`)
@@ -1068,15 +1067,15 @@ class Parcats(_BaseTraceType):
             only when this field is shown. Numbers are formatted
             using d3-format's syntax %{variable:d3-format}, for
             example "Price: %{y:$.2f}".
-            https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format for
-            details on the formatting syntax. Dates are formatted
-            using d3-time-format's syntax %{variable|d3-time-
-            format}, for example "Day: %{2019-01-01|%A}".
-            https://github.com/d3/d3-time-format#locale_format for
-            details on the date formatting syntax. The variables
-            available in `hovertemplate` are the ones emitted as
-            event data described at this link
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format
+            for details on the formatting syntax. Dates are
+            formatted using d3-time-format's syntax
+            %{variable|d3-time-format}, for example "Day:
+            %{2019-01-01|%A}". https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format for details on the
+            date formatting syntax. The variables available in
+            `hovertemplate` are the ones emitted as event data
+            described at this link
             https://plotly.com/javascript/plotlyjs-events/#event-
             data. Additionally, every attributes that can be
             specified per-point (the ones that are `arrayOk: true`)
