@@ -28,6 +28,8 @@ class Streamtube(_BaseTraceType):
         "ids",
         "idssrc",
         "legendgroup",
+        "legendgrouptitle",
+        "legendrank",
         "lighting",
         "lightposition",
         "maxdisplayed",
@@ -45,19 +47,25 @@ class Streamtube(_BaseTraceType):
         "text",
         "type",
         "u",
+        "uhoverformat",
         "uid",
         "uirevision",
         "usrc",
         "v",
+        "vhoverformat",
         "visible",
         "vsrc",
         "w",
+        "whoverformat",
         "wsrc",
         "x",
+        "xhoverformat",
         "xsrc",
         "y",
+        "yhoverformat",
         "ysrc",
         "z",
+        "zhoverformat",
         "zsrc",
     }
 
@@ -334,16 +342,17 @@ class Streamtube(_BaseTraceType):
                 tickformat
                     Sets the tick label formatting rule using d3
                     formatting mini-languages which are very
-                    similar to those in Python. For numbers, see:
-                    https://github.com/d3/d3-3.x-api-
-                    reference/blob/master/Formatting.md#d3_format
-                    And for dates see:
+                    similar to those in Python. For numbers, see: h
+                    ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                    ormat. And for dates see:
                     https://github.com/d3/d3-time-
-                    format#locale_format We add one item to d3's
-                    date formatter: "%{n}f" for fractional seconds
-                    with n digits. For example, *2016-10-13
-                    09:15:23.456* with tickformat "%H~%M~%S.%2f"
-                    would display "09~15~23.46"
+                    format/tree/v2.2.3#locale_format. We add two
+                    items to d3's date formatter: "%h" for half of
+                    the year as a decimal number as well as "%{n}f"
+                    for fractional seconds with n digits. For
+                    example, *2016-10-13 09:15:23.456* with
+                    tickformat "%H~%M~%S.%2f" would display
+                    "09~15~23.46"
                 tickformatstops
                     A tuple of :class:`plotly.graph_objects.streamt
                     ube.colorbar.Tickformatstop` instances or dicts
@@ -353,6 +362,12 @@ class Streamtube(_BaseTraceType):
                     a.streamtube.colorbar.tickformatstopdefaults),
                     sets the default property values to use for
                     elements of streamtube.colorbar.tickformatstops
+                ticklabeloverflow
+                    Determines how we handle tick labels that would
+                    overflow either the graph div or the domain of
+                    the axis. The default value for inside tick
+                    labels is *hide past domain*. In other cases
+                    the default is *hide past div*.
                 ticklabelposition
                     Determines where tick labels are drawn.
                 ticklen
@@ -455,9 +470,9 @@ class Streamtube(_BaseTraceType):
         `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To control the
         bounds of the colorscale in color space, use`cmin` and `cmax`.
         Alternatively, `colorscale` may be a palette name string of the
-        following list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu,Reds,Bl
-        ues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,Earth,Electric,Vi
-        ridis,Cividis.
+        following list: Blackbody,Bluered,Blues,Cividis,Earth,Electric,
+        Greens,Greys,Hot,Jet,Picnic,Portland,Rainbow,RdBu,Reds,Viridis,
+        YlGnBu,YlOrRd.
     
         The 'colorscale' property is a colorscale and may be
         specified as:
@@ -653,17 +668,21 @@ class Streamtube(_BaseTraceType):
         """
         Template string used for rendering the information that appear
         on hover box. Note that this will override `hoverinfo`.
-        Variables are inserted using %{variable}, for example "y:
-        %{y}". Numbers are formatted using d3-format's syntax
-        %{variable:d3-format}, for example "Price: %{y:$.2f}".
-        https://github.com/d3/d3-3.x-api-
-        reference/blob/master/Formatting.md#d3_format for details on
-        the formatting syntax. Dates are formatted using d3-time-
-        format's syntax %{variable|d3-time-format}, for example "Day:
-        %{2019-01-01|%A}". https://github.com/d3/d3-time-
-        format#locale_format for details on the date formatting syntax.
-        The variables available in `hovertemplate` are the ones emitted
-        as event data described at this link
+        Variables are inserted using %{variable}, for example "y: %{y}"
+        as well as %{xother}, {%_xother}, {%_xother_}, {%xother_}. When
+        showing info for several points, "xother" will be added to
+        those with different x positions from the first point. An
+        underscore before or after "(x|y)other" will add a space on
+        that side, only when this field is shown. Numbers are formatted
+        using d3-format's syntax %{variable:d3-format}, for example
+        "Price: %{y:$.2f}".
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format for
+        details on the formatting syntax. Dates are formatted using
+        d3-time-format's syntax %{variable|d3-time-format}, for example
+        "Day: %{2019-01-01|%A}". https://github.com/d3/d3-time-
+        format/tree/v2.2.3#locale_format for details on the date
+        formatting syntax. The variables available in `hovertemplate`
+        are the ones emitted as event data described at this link
         https://plotly.com/javascript/plotlyjs-events/#event-data.
         Additionally, every attributes that can be specified per-point
         (the ones that are `arrayOk: true`) are available. variables
@@ -795,6 +814,59 @@ class Streamtube(_BaseTraceType):
     def legendgroup(self, val):
         self["legendgroup"] = val
 
+    # legendgrouptitle
+    # ----------------
+    @property
+    def legendgrouptitle(self):
+        """
+        The 'legendgrouptitle' property is an instance of Legendgrouptitle
+        that may be specified as:
+          - An instance of :class:`plotly.graph_objs.streamtube.Legendgrouptitle`
+          - A dict of string/value properties that will be passed
+            to the Legendgrouptitle constructor
+    
+            Supported dict properties:
+                
+                font
+                    Sets this legend group's title font.
+                text
+                    Sets the title of the legend group.
+
+        Returns
+        -------
+        plotly.graph_objs.streamtube.Legendgrouptitle
+        """
+        return self["legendgrouptitle"]
+
+    @legendgrouptitle.setter
+    def legendgrouptitle(self, val):
+        self["legendgrouptitle"] = val
+
+    # legendrank
+    # ----------
+    @property
+    def legendrank(self):
+        """
+        Sets the legend rank for this trace. Items and groups with
+        smaller ranks are presented on top/left side while with
+        `*reversed* `legend.traceorder` they are on bottom/right side.
+        The default legendrank is 1000, so that you can use ranks less
+        than 1000 to place certain items before all unranked items, and
+        ranks greater than 1000 to go after all unranked items.
+    
+        The 'legendrank' property is a number and may be specified as:
+          - An int or float
+
+        Returns
+        -------
+        int|float
+        """
+        return self["legendrank"]
+
+    @legendrank.setter
+    def legendrank(self, val):
+        self["legendrank"] = val
+
     # lighting
     # --------
     @property
@@ -1222,6 +1294,31 @@ class Streamtube(_BaseTraceType):
     def u(self, val):
         self["u"] = val
 
+    # uhoverformat
+    # ------------
+    @property
+    def uhoverformat(self):
+        """
+        Sets the hover text formatting rulefor `u`  using d3 formatting
+        mini-languages which are very similar to those in Python. For
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format.By
+        default the values are formatted using generic number format.
+    
+        The 'uhoverformat' property is a string and must be specified as:
+          - A string
+          - A number that will be converted to a string
+
+        Returns
+        -------
+        str
+        """
+        return self["uhoverformat"]
+
+    @uhoverformat.setter
+    def uhoverformat(self, val):
+        self["uhoverformat"] = val
+
     # uid
     # ---
     @property
@@ -1317,6 +1414,31 @@ class Streamtube(_BaseTraceType):
     def v(self, val):
         self["v"] = val
 
+    # vhoverformat
+    # ------------
+    @property
+    def vhoverformat(self):
+        """
+        Sets the hover text formatting rulefor `v`  using d3 formatting
+        mini-languages which are very similar to those in Python. For
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format.By
+        default the values are formatted using generic number format.
+    
+        The 'vhoverformat' property is a string and must be specified as:
+          - A string
+          - A number that will be converted to a string
+
+        Returns
+        -------
+        str
+        """
+        return self["vhoverformat"]
+
+    @vhoverformat.setter
+    def vhoverformat(self, val):
+        self["vhoverformat"] = val
+
     # visible
     # -------
     @property
@@ -1380,6 +1502,31 @@ class Streamtube(_BaseTraceType):
     def w(self, val):
         self["w"] = val
 
+    # whoverformat
+    # ------------
+    @property
+    def whoverformat(self):
+        """
+        Sets the hover text formatting rulefor `w`  using d3 formatting
+        mini-languages which are very similar to those in Python. For
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format.By
+        default the values are formatted using generic number format.
+    
+        The 'whoverformat' property is a string and must be specified as:
+          - A string
+          - A number that will be converted to a string
+
+        Returns
+        -------
+        str
+        """
+        return self["whoverformat"]
+
+    @whoverformat.setter
+    def whoverformat(self, val):
+        self["whoverformat"] = val
+
     # wsrc
     # ----
     @property
@@ -1420,6 +1567,37 @@ class Streamtube(_BaseTraceType):
     def x(self, val):
         self["x"] = val
 
+    # xhoverformat
+    # ------------
+    @property
+    def xhoverformat(self):
+        """
+        Sets the hover text formatting rulefor `x`  using d3 formatting
+        mini-languages which are very similar to those in Python. For
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format. And for
+        dates see: https://github.com/d3/d3-time-
+        format/tree/v2.2.3#locale_format. We add two items to d3's date
+        formatter: "%h" for half of the year as a decimal number as
+        well as "%{n}f" for fractional seconds with n digits. For
+        example, *2016-10-13 09:15:23.456* with tickformat
+        "%H~%M~%S.%2f" would display *09~15~23.46*By default the values
+        are formatted using `xaxis.hoverformat`.
+    
+        The 'xhoverformat' property is a string and must be specified as:
+          - A string
+          - A number that will be converted to a string
+
+        Returns
+        -------
+        str
+        """
+        return self["xhoverformat"]
+
+    @xhoverformat.setter
+    def xhoverformat(self, val):
+        self["xhoverformat"] = val
+
     # xsrc
     # ----
     @property
@@ -1460,6 +1638,37 @@ class Streamtube(_BaseTraceType):
     def y(self, val):
         self["y"] = val
 
+    # yhoverformat
+    # ------------
+    @property
+    def yhoverformat(self):
+        """
+        Sets the hover text formatting rulefor `y`  using d3 formatting
+        mini-languages which are very similar to those in Python. For
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format. And for
+        dates see: https://github.com/d3/d3-time-
+        format/tree/v2.2.3#locale_format. We add two items to d3's date
+        formatter: "%h" for half of the year as a decimal number as
+        well as "%{n}f" for fractional seconds with n digits. For
+        example, *2016-10-13 09:15:23.456* with tickformat
+        "%H~%M~%S.%2f" would display *09~15~23.46*By default the values
+        are formatted using `yaxis.hoverformat`.
+    
+        The 'yhoverformat' property is a string and must be specified as:
+          - A string
+          - A number that will be converted to a string
+
+        Returns
+        -------
+        str
+        """
+        return self["yhoverformat"]
+
+    @yhoverformat.setter
+    def yhoverformat(self, val):
+        self["yhoverformat"] = val
+
     # ysrc
     # ----
     @property
@@ -1500,6 +1709,37 @@ class Streamtube(_BaseTraceType):
     def z(self, val):
         self["z"] = val
 
+    # zhoverformat
+    # ------------
+    @property
+    def zhoverformat(self):
+        """
+        Sets the hover text formatting rulefor `z`  using d3 formatting
+        mini-languages which are very similar to those in Python. For
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format. And for
+        dates see: https://github.com/d3/d3-time-
+        format/tree/v2.2.3#locale_format. We add two items to d3's date
+        formatter: "%h" for half of the year as a decimal number as
+        well as "%{n}f" for fractional seconds with n digits. For
+        example, *2016-10-13 09:15:23.456* with tickformat
+        "%H~%M~%S.%2f" would display *09~15~23.46*By default the values
+        are formatted using `zaxis.hoverformat`.
+    
+        The 'zhoverformat' property is a string and must be specified as:
+          - A string
+          - A number that will be converted to a string
+
+        Returns
+        -------
+        str
+        """
+        return self["zhoverformat"]
+
+    @zhoverformat.setter
+    def zhoverformat(self, val):
+        self["zhoverformat"] = val
+
     # zsrc
     # ----
     @property
@@ -1575,9 +1815,9 @@ class Streamtube(_BaseTraceType):
             'rgb(255,0,0)']]`. To control the bounds of the
             colorscale in color space, use`cmin` and `cmax`.
             Alternatively, `colorscale` may be a palette name
-            string of the following list: Greys,YlGnBu,Greens,YlOrR
-            d,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,Portland,Jet,H
-            ot,Blackbody,Earth,Electric,Viridis,Cividis.
+            string of the following list: Blackbody,Bluered,Blues,C
+            ividis,Earth,Electric,Greens,Greys,Hot,Jet,Picnic,Portl
+            and,Rainbow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
         customdata
             Assigns extra data each datum. This may be useful when
             listening to hover, click and selection events. Note
@@ -1601,17 +1841,23 @@ class Streamtube(_BaseTraceType):
             Template string used for rendering the information that
             appear on hover box. Note that this will override
             `hoverinfo`. Variables are inserted using %{variable},
-            for example "y: %{y}". Numbers are formatted using
-            d3-format's syntax %{variable:d3-format}, for example
-            "Price: %{y:$.2f}". https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format for
-            details on the formatting syntax. Dates are formatted
-            using d3-time-format's syntax %{variable|d3-time-
-            format}, for example "Day: %{2019-01-01|%A}".
-            https://github.com/d3/d3-time-format#locale_format for
-            details on the date formatting syntax. The variables
-            available in `hovertemplate` are the ones emitted as
-            event data described at this link
+            for example "y: %{y}" as well as %{xother}, {%_xother},
+            {%_xother_}, {%xother_}. When showing info for several
+            points, "xother" will be added to those with different
+            x positions from the first point. An underscore before
+            or after "(x|y)other" will add a space on that side,
+            only when this field is shown. Numbers are formatted
+            using d3-format's syntax %{variable:d3-format}, for
+            example "Price: %{y:$.2f}".
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format
+            for details on the formatting syntax. Dates are
+            formatted using d3-time-format's syntax
+            %{variable|d3-time-format}, for example "Day:
+            %{2019-01-01|%A}". https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format for details on the
+            date formatting syntax. The variables available in
+            `hovertemplate` are the ones emitted as event data
+            described at this link
             https://plotly.com/javascript/plotlyjs-events/#event-
             data. Additionally, every attributes that can be
             specified per-point (the ones that are `arrayOk: true`)
@@ -1637,6 +1883,17 @@ class Streamtube(_BaseTraceType):
             Sets the legend group for this trace. Traces part of
             the same legend group hide/show at the same time when
             toggling legend items.
+        legendgrouptitle
+            :class:`plotly.graph_objects.streamtube.Legendgrouptitl
+            e` instance or dict with compatible properties
+        legendrank
+            Sets the legend rank for this trace. Items and groups
+            with smaller ranks are presented on top/left side while
+            with `*reversed* `legend.traceorder` they are on
+            bottom/right side. The default legendrank is 1000, so
+            that you can use ranks less than 1000 to place certain
+            items before all unranked items, and ranks greater than
+            1000 to go after all unranked items.
         lighting
             :class:`plotly.graph_objects.streamtube.Lighting`
             instance or dict with compatible properties
@@ -1706,6 +1963,12 @@ class Streamtube(_BaseTraceType):
             streamtube traces do not support array `text` values.
         u
             Sets the x components of the vector field.
+        uhoverformat
+            Sets the hover text formatting rulefor `u`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see: https://github.com/d
+            3/d3-format/tree/v1.4.5#d3-format.By default the values
+            are formatted using generic number format.
         uid
             Assign an id to this trace, Use this to provide object
             constancy between traces during animations and
@@ -1733,6 +1996,12 @@ class Streamtube(_BaseTraceType):
             .
         v
             Sets the y components of the vector field.
+        vhoverformat
+            Sets the hover text formatting rulefor `v`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see: https://github.com/d
+            3/d3-format/tree/v1.4.5#d3-format.By default the values
+            are formatted using generic number format.
         visible
             Determines whether or not this trace is visible. If
             "legendonly", the trace is not drawn, but can appear as
@@ -1743,21 +2012,66 @@ class Streamtube(_BaseTraceType):
             .
         w
             Sets the z components of the vector field.
+        whoverformat
+            Sets the hover text formatting rulefor `w`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see: https://github.com/d
+            3/d3-format/tree/v1.4.5#d3-format.By default the values
+            are formatted using generic number format.
         wsrc
             Sets the source reference on Chart Studio Cloud for  w
             .
         x
             Sets the x coordinates of the vector field.
+        xhoverformat
+            Sets the hover text formatting rulefor `x`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see:
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
+            And for dates see: https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format. We add two items to
+            d3's date formatter: "%h" for half of the year as a
+            decimal number as well as "%{n}f" for fractional
+            seconds with n digits. For example, *2016-10-13
+            09:15:23.456* with tickformat "%H~%M~%S.%2f" would
+            display *09~15~23.46*By default the values are
+            formatted using `xaxis.hoverformat`.
         xsrc
             Sets the source reference on Chart Studio Cloud for  x
             .
         y
             Sets the y coordinates of the vector field.
+        yhoverformat
+            Sets the hover text formatting rulefor `y`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see:
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
+            And for dates see: https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format. We add two items to
+            d3's date formatter: "%h" for half of the year as a
+            decimal number as well as "%{n}f" for fractional
+            seconds with n digits. For example, *2016-10-13
+            09:15:23.456* with tickformat "%H~%M~%S.%2f" would
+            display *09~15~23.46*By default the values are
+            formatted using `yaxis.hoverformat`.
         ysrc
             Sets the source reference on Chart Studio Cloud for  y
             .
         z
             Sets the z coordinates of the vector field.
+        zhoverformat
+            Sets the hover text formatting rulefor `z`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see:
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
+            And for dates see: https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format. We add two items to
+            d3's date formatter: "%h" for half of the year as a
+            decimal number as well as "%{n}f" for fractional
+            seconds with n digits. For example, *2016-10-13
+            09:15:23.456* with tickformat "%H~%M~%S.%2f" would
+            display *09~15~23.46*By default the values are
+            formatted using `zaxis.hoverformat`.
         zsrc
             Sets the source reference on Chart Studio Cloud for  z
             .
@@ -1785,6 +2099,8 @@ class Streamtube(_BaseTraceType):
         ids=None,
         idssrc=None,
         legendgroup=None,
+        legendgrouptitle=None,
+        legendrank=None,
         lighting=None,
         lightposition=None,
         maxdisplayed=None,
@@ -1801,19 +2117,25 @@ class Streamtube(_BaseTraceType):
         stream=None,
         text=None,
         u=None,
+        uhoverformat=None,
         uid=None,
         uirevision=None,
         usrc=None,
         v=None,
+        vhoverformat=None,
         visible=None,
         vsrc=None,
         w=None,
+        whoverformat=None,
         wsrc=None,
         x=None,
+        xhoverformat=None,
         xsrc=None,
         y=None,
+        yhoverformat=None,
         ysrc=None,
         z=None,
+        zhoverformat=None,
         zsrc=None,
         **kwargs
     ):
@@ -1879,9 +2201,9 @@ class Streamtube(_BaseTraceType):
             'rgb(255,0,0)']]`. To control the bounds of the
             colorscale in color space, use`cmin` and `cmax`.
             Alternatively, `colorscale` may be a palette name
-            string of the following list: Greys,YlGnBu,Greens,YlOrR
-            d,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,Portland,Jet,H
-            ot,Blackbody,Earth,Electric,Viridis,Cividis.
+            string of the following list: Blackbody,Bluered,Blues,C
+            ividis,Earth,Electric,Greens,Greys,Hot,Jet,Picnic,Portl
+            and,Rainbow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
         customdata
             Assigns extra data each datum. This may be useful when
             listening to hover, click and selection events. Note
@@ -1905,17 +2227,23 @@ class Streamtube(_BaseTraceType):
             Template string used for rendering the information that
             appear on hover box. Note that this will override
             `hoverinfo`. Variables are inserted using %{variable},
-            for example "y: %{y}". Numbers are formatted using
-            d3-format's syntax %{variable:d3-format}, for example
-            "Price: %{y:$.2f}". https://github.com/d3/d3-3.x-api-
-            reference/blob/master/Formatting.md#d3_format for
-            details on the formatting syntax. Dates are formatted
-            using d3-time-format's syntax %{variable|d3-time-
-            format}, for example "Day: %{2019-01-01|%A}".
-            https://github.com/d3/d3-time-format#locale_format for
-            details on the date formatting syntax. The variables
-            available in `hovertemplate` are the ones emitted as
-            event data described at this link
+            for example "y: %{y}" as well as %{xother}, {%_xother},
+            {%_xother_}, {%xother_}. When showing info for several
+            points, "xother" will be added to those with different
+            x positions from the first point. An underscore before
+            or after "(x|y)other" will add a space on that side,
+            only when this field is shown. Numbers are formatted
+            using d3-format's syntax %{variable:d3-format}, for
+            example "Price: %{y:$.2f}".
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format
+            for details on the formatting syntax. Dates are
+            formatted using d3-time-format's syntax
+            %{variable|d3-time-format}, for example "Day:
+            %{2019-01-01|%A}". https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format for details on the
+            date formatting syntax. The variables available in
+            `hovertemplate` are the ones emitted as event data
+            described at this link
             https://plotly.com/javascript/plotlyjs-events/#event-
             data. Additionally, every attributes that can be
             specified per-point (the ones that are `arrayOk: true`)
@@ -1941,6 +2269,17 @@ class Streamtube(_BaseTraceType):
             Sets the legend group for this trace. Traces part of
             the same legend group hide/show at the same time when
             toggling legend items.
+        legendgrouptitle
+            :class:`plotly.graph_objects.streamtube.Legendgrouptitl
+            e` instance or dict with compatible properties
+        legendrank
+            Sets the legend rank for this trace. Items and groups
+            with smaller ranks are presented on top/left side while
+            with `*reversed* `legend.traceorder` they are on
+            bottom/right side. The default legendrank is 1000, so
+            that you can use ranks less than 1000 to place certain
+            items before all unranked items, and ranks greater than
+            1000 to go after all unranked items.
         lighting
             :class:`plotly.graph_objects.streamtube.Lighting`
             instance or dict with compatible properties
@@ -2010,6 +2349,12 @@ class Streamtube(_BaseTraceType):
             streamtube traces do not support array `text` values.
         u
             Sets the x components of the vector field.
+        uhoverformat
+            Sets the hover text formatting rulefor `u`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see: https://github.com/d
+            3/d3-format/tree/v1.4.5#d3-format.By default the values
+            are formatted using generic number format.
         uid
             Assign an id to this trace, Use this to provide object
             constancy between traces during animations and
@@ -2037,6 +2382,12 @@ class Streamtube(_BaseTraceType):
             .
         v
             Sets the y components of the vector field.
+        vhoverformat
+            Sets the hover text formatting rulefor `v`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see: https://github.com/d
+            3/d3-format/tree/v1.4.5#d3-format.By default the values
+            are formatted using generic number format.
         visible
             Determines whether or not this trace is visible. If
             "legendonly", the trace is not drawn, but can appear as
@@ -2047,21 +2398,66 @@ class Streamtube(_BaseTraceType):
             .
         w
             Sets the z components of the vector field.
+        whoverformat
+            Sets the hover text formatting rulefor `w`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see: https://github.com/d
+            3/d3-format/tree/v1.4.5#d3-format.By default the values
+            are formatted using generic number format.
         wsrc
             Sets the source reference on Chart Studio Cloud for  w
             .
         x
             Sets the x coordinates of the vector field.
+        xhoverformat
+            Sets the hover text formatting rulefor `x`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see:
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
+            And for dates see: https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format. We add two items to
+            d3's date formatter: "%h" for half of the year as a
+            decimal number as well as "%{n}f" for fractional
+            seconds with n digits. For example, *2016-10-13
+            09:15:23.456* with tickformat "%H~%M~%S.%2f" would
+            display *09~15~23.46*By default the values are
+            formatted using `xaxis.hoverformat`.
         xsrc
             Sets the source reference on Chart Studio Cloud for  x
             .
         y
             Sets the y coordinates of the vector field.
+        yhoverformat
+            Sets the hover text formatting rulefor `y`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see:
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
+            And for dates see: https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format. We add two items to
+            d3's date formatter: "%h" for half of the year as a
+            decimal number as well as "%{n}f" for fractional
+            seconds with n digits. For example, *2016-10-13
+            09:15:23.456* with tickformat "%H~%M~%S.%2f" would
+            display *09~15~23.46*By default the values are
+            formatted using `yaxis.hoverformat`.
         ysrc
             Sets the source reference on Chart Studio Cloud for  y
             .
         z
             Sets the z coordinates of the vector field.
+        zhoverformat
+            Sets the hover text formatting rulefor `z`  using d3
+            formatting mini-languages which are very similar to
+            those in Python. For numbers, see:
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
+            And for dates see: https://github.com/d3/d3-time-
+            format/tree/v2.2.3#locale_format. We add two items to
+            d3's date formatter: "%h" for half of the year as a
+            decimal number as well as "%{n}f" for fractional
+            seconds with n digits. For example, *2016-10-13
+            09:15:23.456* with tickformat "%H~%M~%S.%2f" would
+            display *09~15~23.46*By default the values are
+            formatted using `zaxis.hoverformat`.
         zsrc
             Sets the source reference on Chart Studio Cloud for  z
             .
@@ -2175,6 +2571,14 @@ an instance of :class:`plotly.graph_objs.Streamtube`"""
         _v = legendgroup if legendgroup is not None else _v
         if _v is not None:
             self["legendgroup"] = _v
+        _v = arg.pop("legendgrouptitle", None)
+        _v = legendgrouptitle if legendgrouptitle is not None else _v
+        if _v is not None:
+            self["legendgrouptitle"] = _v
+        _v = arg.pop("legendrank", None)
+        _v = legendrank if legendrank is not None else _v
+        if _v is not None:
+            self["legendrank"] = _v
         _v = arg.pop("lighting", None)
         _v = lighting if lighting is not None else _v
         if _v is not None:
@@ -2239,6 +2643,10 @@ an instance of :class:`plotly.graph_objs.Streamtube`"""
         _v = u if u is not None else _v
         if _v is not None:
             self["u"] = _v
+        _v = arg.pop("uhoverformat", None)
+        _v = uhoverformat if uhoverformat is not None else _v
+        if _v is not None:
+            self["uhoverformat"] = _v
         _v = arg.pop("uid", None)
         _v = uid if uid is not None else _v
         if _v is not None:
@@ -2255,6 +2663,10 @@ an instance of :class:`plotly.graph_objs.Streamtube`"""
         _v = v if v is not None else _v
         if _v is not None:
             self["v"] = _v
+        _v = arg.pop("vhoverformat", None)
+        _v = vhoverformat if vhoverformat is not None else _v
+        if _v is not None:
+            self["vhoverformat"] = _v
         _v = arg.pop("visible", None)
         _v = visible if visible is not None else _v
         if _v is not None:
@@ -2267,6 +2679,10 @@ an instance of :class:`plotly.graph_objs.Streamtube`"""
         _v = w if w is not None else _v
         if _v is not None:
             self["w"] = _v
+        _v = arg.pop("whoverformat", None)
+        _v = whoverformat if whoverformat is not None else _v
+        if _v is not None:
+            self["whoverformat"] = _v
         _v = arg.pop("wsrc", None)
         _v = wsrc if wsrc is not None else _v
         if _v is not None:
@@ -2275,6 +2691,10 @@ an instance of :class:`plotly.graph_objs.Streamtube`"""
         _v = x if x is not None else _v
         if _v is not None:
             self["x"] = _v
+        _v = arg.pop("xhoverformat", None)
+        _v = xhoverformat if xhoverformat is not None else _v
+        if _v is not None:
+            self["xhoverformat"] = _v
         _v = arg.pop("xsrc", None)
         _v = xsrc if xsrc is not None else _v
         if _v is not None:
@@ -2283,6 +2703,10 @@ an instance of :class:`plotly.graph_objs.Streamtube`"""
         _v = y if y is not None else _v
         if _v is not None:
             self["y"] = _v
+        _v = arg.pop("yhoverformat", None)
+        _v = yhoverformat if yhoverformat is not None else _v
+        if _v is not None:
+            self["yhoverformat"] = _v
         _v = arg.pop("ysrc", None)
         _v = ysrc if ysrc is not None else _v
         if _v is not None:
@@ -2291,6 +2715,10 @@ an instance of :class:`plotly.graph_objs.Streamtube`"""
         _v = z if z is not None else _v
         if _v is not None:
             self["z"] = _v
+        _v = arg.pop("zhoverformat", None)
+        _v = zhoverformat if zhoverformat is not None else _v
+        if _v is not None:
+            self["zhoverformat"] = _v
         _v = arg.pop("zsrc", None)
         _v = zsrc if zsrc is not None else _v
         if _v is not None:
