@@ -371,16 +371,17 @@ class Marker(_BaseTraceHierarchyType):
                 tickformat
                     Sets the tick label formatting rule using d3
                     formatting mini-languages which are very
-                    similar to those in Python. For numbers, see:
-                    https://github.com/d3/d3-3.x-api-
-                    reference/blob/master/Formatting.md#d3_format
-                    And for dates see:
+                    similar to those in Python. For numbers, see: h
+                    ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                    ormat. And for dates see:
                     https://github.com/d3/d3-time-
-                    format#locale_format We add one item to d3's
-                    date formatter: "%{n}f" for fractional seconds
-                    with n digits. For example, *2016-10-13
-                    09:15:23.456* with tickformat "%H~%M~%S.%2f"
-                    would display "09~15~23.46"
+                    format/tree/v2.2.3#locale_format. We add two
+                    items to d3's date formatter: "%h" for half of
+                    the year as a decimal number as well as "%{n}f"
+                    for fractional seconds with n digits. For
+                    example, *2016-10-13 09:15:23.456* with
+                    tickformat "%H~%M~%S.%2f" would display
+                    "09~15~23.46"
                 tickformatstops
                     A tuple of :class:`plotly.graph_objects.histogr
                     am.marker.colorbar.Tickformatstop` instances or
@@ -500,9 +501,9 @@ class Marker(_BaseTraceHierarchyType):
         example, `[[0, 'rgb(0,0,255)'], [1, 'rgb(255,0,0)']]`. To
         control the bounds of the colorscale in color space,
         use`marker.cmin` and `marker.cmax`. Alternatively, `colorscale`
-        may be a palette name string of the following list: Greys,YlGnB
-        u,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,Picnic,Rainbow,Portland
-        ,Jet,Hot,Blackbody,Earth,Electric,Viridis,Cividis.
+        may be a palette name string of the following list: Blackbody,B
+        luered,Blues,Cividis,Earth,Electric,Greens,Greys,Hot,Jet,Picnic
+        ,Portland,Rainbow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
     
         The 'colorscale' property is a colorscale and may be
         specified as:
@@ -643,9 +644,9 @@ class Marker(_BaseTraceHierarchyType):
                     color space, use`marker.line.cmin` and
                     `marker.line.cmax`. Alternatively, `colorscale`
                     may be a palette name string of the following
-                    list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu,R
-                    eds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Black
-                    body,Earth,Electric,Viridis,Cividis.
+                    list: Blackbody,Bluered,Blues,Cividis,Earth,Ele
+                    ctric,Greens,Greys,Hot,Jet,Picnic,Portland,Rain
+                    bow,RdBu,Reds,Viridis,YlGnBu,YlOrRd.
                 colorsrc
                     Sets the source reference on Chart Studio Cloud
                     for  color .
@@ -898,9 +899,9 @@ class Marker(_BaseTraceHierarchyType):
             To control the bounds of the colorscale in color space,
             use`marker.cmin` and `marker.cmax`. Alternatively,
             `colorscale` may be a palette name string of the
-            following list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu
-            ,Reds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
-            arth,Electric,Viridis,Cividis.
+            following list: Blackbody,Bluered,Blues,Cividis,Earth,E
+            lectric,Greens,Greys,Hot,Jet,Picnic,Portland,Rainbow,Rd
+            Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
             color .
@@ -1016,9 +1017,9 @@ class Marker(_BaseTraceHierarchyType):
             To control the bounds of the colorscale in color space,
             use`marker.cmin` and `marker.cmax`. Alternatively,
             `colorscale` may be a palette name string of the
-            following list: Greys,YlGnBu,Greens,YlOrRd,Bluered,RdBu
-            ,Reds,Blues,Picnic,Rainbow,Portland,Jet,Hot,Blackbody,E
-            arth,Electric,Viridis,Cividis.
+            following list: Blackbody,Bluered,Blues,Cividis,Earth,E
+            lectric,Greens,Greys,Hot,Jet,Picnic,Portland,Rainbow,Rd
+            Bu,Reds,Viridis,YlGnBu,YlOrRd.
         colorsrc
             Sets the source reference on Chart Studio Cloud for
             color .
