@@ -9,7 +9,6 @@ class Data(_BaseLayoutHierarchyType):
     _parent_path_str = "layout.template"
     _path_str = "layout.template.data"
     _valid_props = {
-        "area",
         "bar",
         "barpolar",
         "box",
@@ -28,6 +27,7 @@ class Data(_BaseLayoutHierarchyType):
         "histogram",
         "histogram2d",
         "histogram2dcontour",
+        "icicle",
         "image",
         "indicator",
         "isosurface",
@@ -58,29 +58,6 @@ class Data(_BaseLayoutHierarchyType):
         "waterfall",
     }
 
-    # area
-    # ----
-    @property
-    def area(self):
-        """
-        The 'area' property is a tuple of instances of
-        Area that may be specified as:
-          - A list or tuple of instances of plotly.graph_objs.layout.template.data.Area
-          - A list or tuple of dicts of string/value properties that
-            will be passed to the Area constructor
-    
-            Supported dict properties:
-
-        Returns
-        -------
-        tuple[plotly.graph_objs.layout.template.data.Area]
-        """
-        return self["area"]
-
-    @area.setter
-    def area(self, val):
-        self["area"] = val
-
     # barpolar
     # --------
     @property
@@ -495,6 +472,29 @@ class Data(_BaseLayoutHierarchyType):
     def histogram(self, val):
         self["histogram"] = val
 
+    # icicle
+    # ------
+    @property
+    def icicle(self):
+        """
+        The 'icicle' property is a tuple of instances of
+        Icicle that may be specified as:
+          - A list or tuple of instances of plotly.graph_objs.layout.template.data.Icicle
+          - A list or tuple of dicts of string/value properties that
+            will be passed to the Icicle constructor
+    
+            Supported dict properties:
+
+        Returns
+        -------
+        tuple[plotly.graph_objs.layout.template.data.Icicle]
+        """
+        return self["icicle"]
+
+    @icicle.setter
+    def icicle(self, val):
+        self["icicle"] = val
+
     # image
     # -----
     @property
@@ -1144,9 +1144,6 @@ class Data(_BaseLayoutHierarchyType):
     @property
     def _prop_descriptions(self):
         return """\
-        area
-            A tuple of :class:`plotly.graph_objects.Area` instances
-            or dicts with compatible properties
         barpolar
             A tuple of :class:`plotly.graph_objects.Barpolar`
             instances or dicts with compatible properties
@@ -1203,6 +1200,9 @@ class Data(_BaseLayoutHierarchyType):
         histogram
             A tuple of :class:`plotly.graph_objects.Histogram`
             instances or dicts with compatible properties
+        icicle
+            A tuple of :class:`plotly.graph_objects.Icicle`
+            instances or dicts with compatible properties
         image
             A tuple of :class:`plotly.graph_objects.Image`
             instances or dicts with compatible properties
@@ -1292,7 +1292,6 @@ class Data(_BaseLayoutHierarchyType):
     def __init__(
         self,
         arg=None,
-        area=None,
         barpolar=None,
         bar=None,
         box=None,
@@ -1311,6 +1310,7 @@ class Data(_BaseLayoutHierarchyType):
         histogram2dcontour=None,
         histogram2d=None,
         histogram=None,
+        icicle=None,
         image=None,
         indicator=None,
         isosurface=None,
@@ -1350,9 +1350,6 @@ class Data(_BaseLayoutHierarchyType):
             dict of properties compatible with this constructor or
             an instance of
             :class:`plotly.graph_objs.layout.template.Data`
-        area
-            A tuple of :class:`plotly.graph_objects.Area` instances
-            or dicts with compatible properties
         barpolar
             A tuple of :class:`plotly.graph_objects.Barpolar`
             instances or dicts with compatible properties
@@ -1409,6 +1406,9 @@ class Data(_BaseLayoutHierarchyType):
         histogram
             A tuple of :class:`plotly.graph_objects.Histogram`
             instances or dicts with compatible properties
+        icicle
+            A tuple of :class:`plotly.graph_objects.Icicle`
+            instances or dicts with compatible properties
         image
             A tuple of :class:`plotly.graph_objects.Image`
             instances or dicts with compatible properties
@@ -1527,10 +1527,6 @@ an instance of :class:`plotly.graph_objs.layout.template.Data`"""
 
         # Populate data dict with properties
         # ----------------------------------
-        _v = arg.pop("area", None)
-        _v = area if area is not None else _v
-        if _v is not None:
-            self["area"] = _v
         _v = arg.pop("barpolar", None)
         _v = barpolar if barpolar is not None else _v
         if _v is not None:
@@ -1603,6 +1599,10 @@ an instance of :class:`plotly.graph_objs.layout.template.Data`"""
         _v = histogram if histogram is not None else _v
         if _v is not None:
             self["histogram"] = _v
+        _v = arg.pop("icicle", None)
+        _v = icicle if icicle is not None else _v
+        if _v is not None:
+            self["icicle"] = _v
         _v = arg.pop("image", None)
         _v = image if image is not None else _v
         if _v is not None:
