@@ -1,8 +1,29 @@
-from plotly.basedatatypes import BaseTraceHierarchyType
-import copy
+from plotly.basedatatypes import BaseTraceHierarchyType as _BaseTraceHierarchyType
+import copy as _copy
 
 
-class Header(BaseTraceHierarchyType):
+class Header(_BaseTraceHierarchyType):
+
+    # class properties
+    # --------------------
+    _parent_path_str = "table"
+    _path_str = "table.header"
+    _valid_props = {
+        "align",
+        "alignsrc",
+        "fill",
+        "font",
+        "format",
+        "formatsrc",
+        "height",
+        "line",
+        "prefix",
+        "prefixsrc",
+        "suffix",
+        "suffixsrc",
+        "values",
+        "valuessrc",
+    }
 
     # align
     # -----
@@ -10,9 +31,9 @@ class Header(BaseTraceHierarchyType):
     def align(self):
         """
         Sets the horizontal alignment of the `text` within the box. Has
-        an effect only if `text` spans more two or more lines (i.e.
-        `text` contains one or more <br> HTML tags) or if an explicit
-        width is set to override the text width.
+        an effect only if `text` spans two or more lines (i.e. `text`
+        contains one or more <br> HTML tags) or if an explicit width is
+        set to override the text width.
     
         The 'align' property is an enumeration that may be specified as:
           - One of the following enumeration values:
@@ -23,18 +44,18 @@ class Header(BaseTraceHierarchyType):
         -------
         Any|numpy.ndarray
         """
-        return self['align']
+        return self["align"]
 
     @align.setter
     def align(self, val):
-        self['align'] = val
+        self["align"] = val
 
     # alignsrc
     # --------
     @property
     def alignsrc(self):
         """
-        Sets the source reference on plot.ly for  align .
+        Sets the source reference on Chart Studio Cloud for  align .
     
         The 'alignsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -43,11 +64,11 @@ class Header(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['alignsrc']
+        return self["alignsrc"]
 
     @alignsrc.setter
     def alignsrc(self, val):
-        self['alignsrc'] = val
+        self["alignsrc"] = val
 
     # fill
     # ----
@@ -56,7 +77,7 @@ class Header(BaseTraceHierarchyType):
         """
         The 'fill' property is an instance of Fill
         that may be specified as:
-          - An instance of plotly.graph_objs.table.header.Fill
+          - An instance of :class:`plotly.graph_objs.table.header.Fill`
           - A dict of string/value properties that will be passed
             to the Fill constructor
     
@@ -67,18 +88,18 @@ class Header(BaseTraceHierarchyType):
                     specific color or an array of colors or a 2D
                     array of colors.
                 colorsrc
-                    Sets the source reference on plot.ly for  color
-                    .
+                    Sets the source reference on Chart Studio Cloud
+                    for  color .
 
         Returns
         -------
         plotly.graph_objs.table.header.Fill
         """
-        return self['fill']
+        return self["fill"]
 
     @fill.setter
     def fill(self, val):
-        self['fill'] = val
+        self["fill"] = val
 
     # font
     # ----
@@ -87,7 +108,7 @@ class Header(BaseTraceHierarchyType):
         """
         The 'font' property is an instance of Font
         that may be specified as:
-          - An instance of plotly.graph_objs.table.header.Font
+          - An instance of :class:`plotly.graph_objs.table.header.Font`
           - A dict of string/value properties that will be passed
             to the Font constructor
     
@@ -96,8 +117,8 @@ class Header(BaseTraceHierarchyType):
                 color
     
                 colorsrc
-                    Sets the source reference on plot.ly for  color
-                    .
+                    Sets the source reference on Chart Studio Cloud
+                    for  color .
                 family
                     HTML font family - the typeface that will be
                     applied by the web browser. The web browser
@@ -106,32 +127,33 @@ class Header(BaseTraceHierarchyType):
                     Provide multiple font families, separated by
                     commas, to indicate the preference in which to
                     apply fonts if they aren't available on the
-                    system. The plotly service (at https://plot.ly
-                    or on-premise) generates images on a server,
-                    where only a select number of fonts are
-                    installed and supported. These include "Arial",
-                    "Balto", "Courier New", "Droid Sans",, "Droid
-                    Serif", "Droid Sans Mono", "Gravitas One", "Old
+                    system. The Chart Studio Cloud (at
+                    https://chart-studio.plotly.com or on-premise)
+                    generates images on a server, where only a
+                    select number of fonts are installed and
+                    supported. These include "Arial", "Balto",
+                    "Courier New", "Droid Sans",, "Droid Serif",
+                    "Droid Sans Mono", "Gravitas One", "Old
                     Standard TT", "Open Sans", "Overpass", "PT Sans
                     Narrow", "Raleway", "Times New Roman".
                 familysrc
-                    Sets the source reference on plot.ly for
-                    family .
+                    Sets the source reference on Chart Studio Cloud
+                    for  family .
                 size
     
                 sizesrc
-                    Sets the source reference on plot.ly for  size
-                    .
+                    Sets the source reference on Chart Studio Cloud
+                    for  size .
 
         Returns
         -------
         plotly.graph_objs.table.header.Font
         """
-        return self['font']
+        return self["font"]
 
     @font.setter
     def font(self, val):
-        self['font'] = val
+        self["font"] = val
 
     # format
     # ------
@@ -139,8 +161,9 @@ class Header(BaseTraceHierarchyType):
     def format(self):
         """
         Sets the cell value formatting rule using d3 formatting mini-
-        language which is similar to those of Python. See https://githu
-        b.com/d3/d3-format/blob/master/README.md#locale_format
+        languages which are very similar to those in Python. For
+        numbers, see:
+        https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
     
         The 'format' property is an array that may be specified as a tuple,
         list, numpy array, or pandas Series
@@ -149,18 +172,18 @@ class Header(BaseTraceHierarchyType):
         -------
         numpy.ndarray
         """
-        return self['format']
+        return self["format"]
 
     @format.setter
     def format(self, val):
-        self['format'] = val
+        self["format"] = val
 
     # formatsrc
     # ---------
     @property
     def formatsrc(self):
         """
-        Sets the source reference on plot.ly for  format .
+        Sets the source reference on Chart Studio Cloud for  format .
     
         The 'formatsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -169,11 +192,11 @@ class Header(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['formatsrc']
+        return self["formatsrc"]
 
     @formatsrc.setter
     def formatsrc(self, val):
-        self['formatsrc'] = val
+        self["formatsrc"] = val
 
     # height
     # ------
@@ -189,11 +212,11 @@ class Header(BaseTraceHierarchyType):
         -------
         int|float
         """
-        return self['height']
+        return self["height"]
 
     @height.setter
     def height(self, val):
-        self['height'] = val
+        self["height"] = val
 
     # line
     # ----
@@ -202,7 +225,7 @@ class Header(BaseTraceHierarchyType):
         """
         The 'line' property is an instance of Line
         that may be specified as:
-          - An instance of plotly.graph_objs.table.header.Line
+          - An instance of :class:`plotly.graph_objs.table.header.Line`
           - A dict of string/value properties that will be passed
             to the Line constructor
     
@@ -211,23 +234,23 @@ class Header(BaseTraceHierarchyType):
                 color
     
                 colorsrc
-                    Sets the source reference on plot.ly for  color
-                    .
+                    Sets the source reference on Chart Studio Cloud
+                    for  color .
                 width
     
                 widthsrc
-                    Sets the source reference on plot.ly for  width
-                    .
+                    Sets the source reference on Chart Studio Cloud
+                    for  width .
 
         Returns
         -------
         plotly.graph_objs.table.header.Line
         """
-        return self['line']
+        return self["line"]
 
     @line.setter
     def line(self, val):
-        self['line'] = val
+        self["line"] = val
 
     # prefix
     # ------
@@ -245,18 +268,18 @@ class Header(BaseTraceHierarchyType):
         -------
         str|numpy.ndarray
         """
-        return self['prefix']
+        return self["prefix"]
 
     @prefix.setter
     def prefix(self, val):
-        self['prefix'] = val
+        self["prefix"] = val
 
     # prefixsrc
     # ---------
     @property
     def prefixsrc(self):
         """
-        Sets the source reference on plot.ly for  prefix .
+        Sets the source reference on Chart Studio Cloud for  prefix .
     
         The 'prefixsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -265,11 +288,11 @@ class Header(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['prefixsrc']
+        return self["prefixsrc"]
 
     @prefixsrc.setter
     def prefixsrc(self, val):
-        self['prefixsrc'] = val
+        self["prefixsrc"] = val
 
     # suffix
     # ------
@@ -287,18 +310,18 @@ class Header(BaseTraceHierarchyType):
         -------
         str|numpy.ndarray
         """
-        return self['suffix']
+        return self["suffix"]
 
     @suffix.setter
     def suffix(self, val):
-        self['suffix'] = val
+        self["suffix"] = val
 
     # suffixsrc
     # ---------
     @property
     def suffixsrc(self):
         """
-        Sets the source reference on plot.ly for  suffix .
+        Sets the source reference on Chart Studio Cloud for  suffix .
     
         The 'suffixsrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -307,11 +330,11 @@ class Header(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['suffixsrc']
+        return self["suffixsrc"]
 
     @suffixsrc.setter
     def suffixsrc(self, val):
-        self['suffixsrc'] = val
+        self["suffixsrc"] = val
 
     # values
     # ------
@@ -330,18 +353,18 @@ class Header(BaseTraceHierarchyType):
         -------
         numpy.ndarray
         """
-        return self['values']
+        return self["values"]
 
     @values.setter
     def values(self, val):
-        self['values'] = val
+        self["values"] = val
 
     # valuessrc
     # ---------
     @property
     def valuessrc(self):
         """
-        Sets the source reference on plot.ly for  values .
+        Sets the source reference on Chart Studio Cloud for  values .
     
         The 'valuessrc' property must be specified as a string or
         as a plotly.grid_objs.Column object
@@ -350,17 +373,11 @@ class Header(BaseTraceHierarchyType):
         -------
         str
         """
-        return self['valuessrc']
+        return self["valuessrc"]
 
     @valuessrc.setter
     def valuessrc(self, val):
-        self['valuessrc'] = val
-
-    # property parent name
-    # --------------------
-    @property
-    def _parent_path_str(self):
-        return 'table'
+        self["valuessrc"] = val
 
     # Self properties description
     # ---------------------------
@@ -369,38 +386,42 @@ class Header(BaseTraceHierarchyType):
         return """\
         align
             Sets the horizontal alignment of the `text` within the
-            box. Has an effect only if `text` spans more two or
-            more lines (i.e. `text` contains one or more <br> HTML
-            tags) or if an explicit width is set to override the
-            text width.
+            box. Has an effect only if `text` spans two or more
+            lines (i.e. `text` contains one or more <br> HTML tags)
+            or if an explicit width is set to override the text
+            width.
         alignsrc
-            Sets the source reference on plot.ly for  align .
+            Sets the source reference on Chart Studio Cloud for
+            align .
         fill
-            plotly.graph_objs.table.header.Fill instance or dict
-            with compatible properties
+            :class:`plotly.graph_objects.table.header.Fill`
+            instance or dict with compatible properties
         font
-            plotly.graph_objs.table.header.Font instance or dict
-            with compatible properties
+            :class:`plotly.graph_objects.table.header.Font`
+            instance or dict with compatible properties
         format
             Sets the cell value formatting rule using d3 formatting
-            mini-language which is similar to those of Python. See 
-            https://github.com/d3/d3-format/blob/master/README.md#l
-            ocale_format
+            mini-languages which are very similar to those in
+            Python. For numbers, see:
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
         formatsrc
-            Sets the source reference on plot.ly for  format .
+            Sets the source reference on Chart Studio Cloud for
+            format .
         height
             The height of cells.
         line
-            plotly.graph_objs.table.header.Line instance or dict
-            with compatible properties
+            :class:`plotly.graph_objects.table.header.Line`
+            instance or dict with compatible properties
         prefix
             Prefix for cell values.
         prefixsrc
-            Sets the source reference on plot.ly for  prefix .
+            Sets the source reference on Chart Studio Cloud for
+            prefix .
         suffix
             Suffix for cell values.
         suffixsrc
-            Sets the source reference on plot.ly for  suffix .
+            Sets the source reference on Chart Studio Cloud for
+            suffix .
         values
             Header cell values. `values[m][n]` represents the value
             of the `n`th point in column `m`, therefore the
@@ -408,7 +429,8 @@ class Header(BaseTraceHierarchyType):
             same (longer vectors will be truncated). Each value
             must be a finite number or a string.
         valuessrc
-            Sets the source reference on plot.ly for  values .
+            Sets the source reference on Chart Studio Cloud for
+            values .
         """
 
     def __init__(
@@ -437,41 +459,45 @@ class Header(BaseTraceHierarchyType):
         ----------
         arg
             dict of properties compatible with this constructor or
-            an instance of plotly.graph_objs.table.Header
+            an instance of :class:`plotly.graph_objs.table.Header`
         align
             Sets the horizontal alignment of the `text` within the
-            box. Has an effect only if `text` spans more two or
-            more lines (i.e. `text` contains one or more <br> HTML
-            tags) or if an explicit width is set to override the
-            text width.
+            box. Has an effect only if `text` spans two or more
+            lines (i.e. `text` contains one or more <br> HTML tags)
+            or if an explicit width is set to override the text
+            width.
         alignsrc
-            Sets the source reference on plot.ly for  align .
+            Sets the source reference on Chart Studio Cloud for
+            align .
         fill
-            plotly.graph_objs.table.header.Fill instance or dict
-            with compatible properties
+            :class:`plotly.graph_objects.table.header.Fill`
+            instance or dict with compatible properties
         font
-            plotly.graph_objs.table.header.Font instance or dict
-            with compatible properties
+            :class:`plotly.graph_objects.table.header.Font`
+            instance or dict with compatible properties
         format
             Sets the cell value formatting rule using d3 formatting
-            mini-language which is similar to those of Python. See 
-            https://github.com/d3/d3-format/blob/master/README.md#l
-            ocale_format
+            mini-languages which are very similar to those in
+            Python. For numbers, see:
+            https://github.com/d3/d3-format/tree/v1.4.5#d3-format.
         formatsrc
-            Sets the source reference on plot.ly for  format .
+            Sets the source reference on Chart Studio Cloud for
+            format .
         height
             The height of cells.
         line
-            plotly.graph_objs.table.header.Line instance or dict
-            with compatible properties
+            :class:`plotly.graph_objects.table.header.Line`
+            instance or dict with compatible properties
         prefix
             Prefix for cell values.
         prefixsrc
-            Sets the source reference on plot.ly for  prefix .
+            Sets the source reference on Chart Studio Cloud for
+            prefix .
         suffix
             Suffix for cell values.
         suffixsrc
-            Sets the source reference on plot.ly for  suffix .
+            Sets the source reference on Chart Studio Cloud for
+            suffix .
         values
             Header cell values. `values[m][n]` represents the value
             of the `n`th point in column `m`, therefore the
@@ -479,13 +505,18 @@ class Header(BaseTraceHierarchyType):
             same (longer vectors will be truncated). Each value
             must be a finite number or a string.
         valuessrc
-            Sets the source reference on plot.ly for  values .
+            Sets the source reference on Chart Studio Cloud for
+            values .
 
         Returns
         -------
         Header
         """
-        super(Header, self).__init__('header')
+        super(Header, self).__init__("header")
+
+        if "_parent" in kwargs:
+            self._parent = kwargs["_parent"]
+            return
 
         # Validate arg
         # ------------
@@ -494,70 +525,78 @@ class Header(BaseTraceHierarchyType):
         elif isinstance(arg, self.__class__):
             arg = arg.to_plotly_json()
         elif isinstance(arg, dict):
-            arg = copy.copy(arg)
+            arg = _copy.copy(arg)
         else:
             raise ValueError(
                 """\
 The first argument to the plotly.graph_objs.table.Header 
 constructor must be a dict or 
-an instance of plotly.graph_objs.table.Header"""
+an instance of :class:`plotly.graph_objs.table.Header`"""
             )
 
         # Handle skip_invalid
         # -------------------
-        self._skip_invalid = kwargs.pop('skip_invalid', False)
-
-        # Import validators
-        # -----------------
-        from plotly.validators.table import (header as v_header)
-
-        # Initialize validators
-        # ---------------------
-        self._validators['align'] = v_header.AlignValidator()
-        self._validators['alignsrc'] = v_header.AlignsrcValidator()
-        self._validators['fill'] = v_header.FillValidator()
-        self._validators['font'] = v_header.FontValidator()
-        self._validators['format'] = v_header.FormatValidator()
-        self._validators['formatsrc'] = v_header.FormatsrcValidator()
-        self._validators['height'] = v_header.HeightValidator()
-        self._validators['line'] = v_header.LineValidator()
-        self._validators['prefix'] = v_header.PrefixValidator()
-        self._validators['prefixsrc'] = v_header.PrefixsrcValidator()
-        self._validators['suffix'] = v_header.SuffixValidator()
-        self._validators['suffixsrc'] = v_header.SuffixsrcValidator()
-        self._validators['values'] = v_header.ValuesValidator()
-        self._validators['valuessrc'] = v_header.ValuessrcValidator()
+        self._skip_invalid = kwargs.pop("skip_invalid", False)
+        self._validate = kwargs.pop("_validate", True)
 
         # Populate data dict with properties
         # ----------------------------------
-        _v = arg.pop('align', None)
-        self['align'] = align if align is not None else _v
-        _v = arg.pop('alignsrc', None)
-        self['alignsrc'] = alignsrc if alignsrc is not None else _v
-        _v = arg.pop('fill', None)
-        self['fill'] = fill if fill is not None else _v
-        _v = arg.pop('font', None)
-        self['font'] = font if font is not None else _v
-        _v = arg.pop('format', None)
-        self['format'] = format if format is not None else _v
-        _v = arg.pop('formatsrc', None)
-        self['formatsrc'] = formatsrc if formatsrc is not None else _v
-        _v = arg.pop('height', None)
-        self['height'] = height if height is not None else _v
-        _v = arg.pop('line', None)
-        self['line'] = line if line is not None else _v
-        _v = arg.pop('prefix', None)
-        self['prefix'] = prefix if prefix is not None else _v
-        _v = arg.pop('prefixsrc', None)
-        self['prefixsrc'] = prefixsrc if prefixsrc is not None else _v
-        _v = arg.pop('suffix', None)
-        self['suffix'] = suffix if suffix is not None else _v
-        _v = arg.pop('suffixsrc', None)
-        self['suffixsrc'] = suffixsrc if suffixsrc is not None else _v
-        _v = arg.pop('values', None)
-        self['values'] = values if values is not None else _v
-        _v = arg.pop('valuessrc', None)
-        self['valuessrc'] = valuessrc if valuessrc is not None else _v
+        _v = arg.pop("align", None)
+        _v = align if align is not None else _v
+        if _v is not None:
+            self["align"] = _v
+        _v = arg.pop("alignsrc", None)
+        _v = alignsrc if alignsrc is not None else _v
+        if _v is not None:
+            self["alignsrc"] = _v
+        _v = arg.pop("fill", None)
+        _v = fill if fill is not None else _v
+        if _v is not None:
+            self["fill"] = _v
+        _v = arg.pop("font", None)
+        _v = font if font is not None else _v
+        if _v is not None:
+            self["font"] = _v
+        _v = arg.pop("format", None)
+        _v = format if format is not None else _v
+        if _v is not None:
+            self["format"] = _v
+        _v = arg.pop("formatsrc", None)
+        _v = formatsrc if formatsrc is not None else _v
+        if _v is not None:
+            self["formatsrc"] = _v
+        _v = arg.pop("height", None)
+        _v = height if height is not None else _v
+        if _v is not None:
+            self["height"] = _v
+        _v = arg.pop("line", None)
+        _v = line if line is not None else _v
+        if _v is not None:
+            self["line"] = _v
+        _v = arg.pop("prefix", None)
+        _v = prefix if prefix is not None else _v
+        if _v is not None:
+            self["prefix"] = _v
+        _v = arg.pop("prefixsrc", None)
+        _v = prefixsrc if prefixsrc is not None else _v
+        if _v is not None:
+            self["prefixsrc"] = _v
+        _v = arg.pop("suffix", None)
+        _v = suffix if suffix is not None else _v
+        if _v is not None:
+            self["suffix"] = _v
+        _v = arg.pop("suffixsrc", None)
+        _v = suffixsrc if suffixsrc is not None else _v
+        if _v is not None:
+            self["suffixsrc"] = _v
+        _v = arg.pop("values", None)
+        _v = values if values is not None else _v
+        if _v is not None:
+            self["values"] = _v
+        _v = arg.pop("valuessrc", None)
+        _v = valuessrc if valuessrc is not None else _v
+        if _v is not None:
+            self["valuessrc"] = _v
 
         # Process unknown kwargs
         # ----------------------
