@@ -40,10 +40,10 @@ class HeatmapglValidator(_plotly_utils.basevalidators.CompoundValidator):
                 'rgb(255,0,0)']]`. To control the bounds of the
                 colorscale in color space, use`zmin` and
                 `zmax`. Alternatively, `colorscale` may be a
-                palette name string of the following list: Grey
-                s,YlGnBu,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,
-                Picnic,Rainbow,Portland,Jet,Hot,Blackbody,Earth
-                ,Electric,Viridis,Cividis.
+                palette name string of the following list: Blac
+                kbody,Bluered,Blues,Cividis,Earth,Electric,Gree
+                ns,Greys,Hot,Jet,Picnic,Portland,Rainbow,RdBu,R
+                eds,Viridis,YlGnBu,YlOrRd.
             customdata
                 Assigns extra data each datum. This may be
                 useful when listening to hover, click and
@@ -79,6 +79,10 @@ class HeatmapglValidator(_plotly_utils.basevalidators.CompoundValidator):
             idssrc
                 Sets the source reference on Chart Studio Cloud
                 for  ids .
+            legendgrouptitle
+                :class:`plotly.graph_objects.heatmapgl.Legendgr
+                ouptitle` instance or dict with compatible
+                properties
             legendrank
                 Sets the legend rank for this trace. Items and
                 groups with smaller ranks are presented on
