@@ -84,10 +84,10 @@ class Mesh3DValidator(_plotly_utils.basevalidators.CompoundValidator):
                 'rgb(255,0,0)']]`. To control the bounds of the
                 colorscale in color space, use`cmin` and
                 `cmax`. Alternatively, `colorscale` may be a
-                palette name string of the following list: Grey
-                s,YlGnBu,Greens,YlOrRd,Bluered,RdBu,Reds,Blues,
-                Picnic,Rainbow,Portland,Jet,Hot,Blackbody,Earth
-                ,Electric,Viridis,Cividis.
+                palette name string of the following list: Blac
+                kbody,Bluered,Blues,Cividis,Earth,Electric,Gree
+                ns,Greys,Hot,Jet,Picnic,Portland,Rainbow,RdBu,R
+                eds,Viridis,YlGnBu,YlOrRd.
             contour
                 :class:`plotly.graph_objects.mesh3d.Contour`
                 instance or dict with compatible properties
@@ -142,17 +142,16 @@ class Mesh3DValidator(_plotly_utils.basevalidators.CompoundValidator):
                 only when this field is shown. Numbers are
                 formatted using d3-format's syntax
                 %{variable:d3-format}, for example "Price:
-                %{y:$.2f}". https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                for details on the formatting syntax. Dates are
-                formatted using d3-time-format's syntax
-                %{variable|d3-time-format}, for example "Day:
-                %{2019-01-01|%A}".
+                %{y:$.2f}". https://github.com/d3/d3-format/tre
+                e/v1.4.5#d3-format for details on the
+                formatting syntax. Dates are formatted using
+                d3-time-format's syntax %{variable|d3-time-
+                format}, for example "Day: %{2019-01-01|%A}".
                 https://github.com/d3/d3-time-
-                format#locale_format for details on the date
-                formatting syntax. The variables available in
-                `hovertemplate` are the ones emitted as event
-                data described at this link
+                format/tree/v2.2.3#locale_format for details on
+                the date formatting syntax. The variables
+                available in `hovertemplate` are the ones
+                emitted as event data described at this link
                 https://plotly.com/javascript/plotlyjs-
                 events/#event-data. Additionally, every
                 attributes that can be specified per-point (the
@@ -362,18 +361,17 @@ class Mesh3DValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the hover text formatting rulefor `x`
                 using d3 formatting mini-languages which are
                 very similar to those in Python. For numbers,
-                see: https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format.
-                And for dates see:
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format. We add two items to d3's
-                date formatter: "%h" for half of the year as a
-                decimal number as well as "%{n}f" for
-                fractional seconds with n digits. For example,
-                *2016-10-13 09:15:23.456* with tickformat
-                "%H~%M~%S.%2f" would display *09~15~23.46*By
-                default the values are formatted using
-                `xaxis.hoverformat`.
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                *09~15~23.46*By default the values are
+                formatted using `xaxis.hoverformat`.
             xsrc
                 Sets the source reference on Chart Studio Cloud
                 for  x .
@@ -389,18 +387,17 @@ class Mesh3DValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the hover text formatting rulefor `y`
                 using d3 formatting mini-languages which are
                 very similar to those in Python. For numbers,
-                see: https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format.
-                And for dates see:
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format. We add two items to d3's
-                date formatter: "%h" for half of the year as a
-                decimal number as well as "%{n}f" for
-                fractional seconds with n digits. For example,
-                *2016-10-13 09:15:23.456* with tickformat
-                "%H~%M~%S.%2f" would display *09~15~23.46*By
-                default the values are formatted using
-                `yaxis.hoverformat`.
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                *09~15~23.46*By default the values are
+                formatted using `yaxis.hoverformat`.
             ysrc
                 Sets the source reference on Chart Studio Cloud
                 for  y .
@@ -416,18 +413,17 @@ class Mesh3DValidator(_plotly_utils.basevalidators.CompoundValidator):
                 Sets the hover text formatting rulefor `z`
                 using d3 formatting mini-languages which are
                 very similar to those in Python. For numbers,
-                see: https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format.
-                And for dates see:
+                see: https://github.com/d3/d3-format/tree/v1.4.
+                5#d3-format. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format. We add two items to d3's
-                date formatter: "%h" for half of the year as a
-                decimal number as well as "%{n}f" for
-                fractional seconds with n digits. For example,
-                *2016-10-13 09:15:23.456* with tickformat
-                "%H~%M~%S.%2f" would display *09~15~23.46*By
-                default the values are formatted using
-                `zaxis.hoverformat`.
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                *09~15~23.46*By default the values are
+                formatted using `zaxis.hoverformat`.
             zsrc
                 Sets the source reference on Chart Studio Cloud
                 for  z .
