@@ -128,16 +128,17 @@ class ColorbarValidator(_plotly_utils.basevalidators.CompoundValidator):
             tickformat
                 Sets the tick label formatting rule using d3
                 formatting mini-languages which are very
-                similar to those in Python. For numbers, see:
-                https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                And for dates see:
+                similar to those in Python. For numbers, see: h
+                ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                ormat. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format We add one item to d3's
-                date formatter: "%{n}f" for fractional seconds
-                with n digits. For example, *2016-10-13
-                09:15:23.456* with tickformat "%H~%M~%S.%2f"
-                would display "09~15~23.46"
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                "09~15~23.46"
             tickformatstops
                 A tuple of :class:`plotly.graph_objects.histogr
                 am2d.colorbar.Tickformatstop` instances or
@@ -148,6 +149,14 @@ class ColorbarValidator(_plotly_utils.basevalidators.CompoundValidator):
                 sets the default property values to use for
                 elements of
                 histogram2d.colorbar.tickformatstops
+            ticklabeloverflow
+                Determines how we handle tick labels that would
+                overflow either the graph div or the domain of
+                the axis. The default value for inside tick
+                labels is *hide past domain*. In other cases
+                the default is *hide past div*.
+            ticklabelposition
+                Determines where tick labels are drawn.
             ticklen
                 Sets the tick length (in px).
             tickmode
