@@ -140,16 +140,17 @@ class YaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
             hoverformat
                 Sets the hover text formatting rule using d3
                 formatting mini-languages which are very
-                similar to those in Python. For numbers, see:
-                https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                And for dates see:
+                similar to those in Python. For numbers, see: h
+                ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                ormat. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format We add one item to d3's
-                date formatter: "%{n}f" for fractional seconds
-                with n digits. For example, *2016-10-13
-                09:15:23.456* with tickformat "%H~%M~%S.%2f"
-                would display "09~15~23.46"
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                "09~15~23.46"
             layer
                 Sets the layer on which this axis is displayed.
                 If *above traces*, this axis is displayed above
@@ -346,16 +347,17 @@ class YaxisValidator(_plotly_utils.basevalidators.CompoundValidator):
             tickformat
                 Sets the tick label formatting rule using d3
                 formatting mini-languages which are very
-                similar to those in Python. For numbers, see:
-                https://github.com/d3/d3-3.x-api-
-                reference/blob/master/Formatting.md#d3_format
-                And for dates see:
+                similar to those in Python. For numbers, see: h
+                ttps://github.com/d3/d3-format/tree/v1.4.5#d3-f
+                ormat. And for dates see:
                 https://github.com/d3/d3-time-
-                format#locale_format We add one item to d3's
-                date formatter: "%{n}f" for fractional seconds
-                with n digits. For example, *2016-10-13
-                09:15:23.456* with tickformat "%H~%M~%S.%2f"
-                would display "09~15~23.46"
+                format/tree/v2.2.3#locale_format. We add two
+                items to d3's date formatter: "%h" for half of
+                the year as a decimal number as well as "%{n}f"
+                for fractional seconds with n digits. For
+                example, *2016-10-13 09:15:23.456* with
+                tickformat "%H~%M~%S.%2f" would display
+                "09~15~23.46"
             tickformatstops
                 A tuple of :class:`plotly.graph_objects.layout.
                 yaxis.Tickformatstop` instances or dicts with
