@@ -10,8 +10,8 @@ class RangeValidator(_plotly_utils.basevalidators.InfoArrayValidator):
             items=kwargs.pop(
                 "items",
                 [
-                    {"valType": "number", "editType": "plot"},
-                    {"valType": "number", "editType": "plot"},
+                    {"editType": "plot", "valType": "number"},
+                    {"editType": "plot", "valType": "number"},
                 ],
             ),
             **kwargs
